ad_library {
  Procedures to supports xowiki portlets.

  @creation-date 2008-02-26
  @author Gustaf Neumann
  @cvs-id $Id: xowiki-portlet-procs.tcl,v 1.5 2024/09/11 06:15:56 gustafn Exp $
}

#
# This is the first approach to make the portlet-procs
#
#  (a) in an oo-style (the object below contains everything
#      for the management of the portlet) and
#  (b) independent from the database layer
#      (supposed to work under postgres and Oracle)
#
# In the next steps, it would make sense to define a ::dotlrn::Portlet
# class, which provides some of the common behavior defined here...
#

Object xowiki_portlet
xowiki_portlet proc name {} {
  return "xowiki-portlet"
}

xowiki_portlet proc pretty_name {} {
  return ""
}

xowiki_portlet proc package_key {} {
  return "xowiki-portlet"
}

xowiki_portlet proc link {} {
  return ""
}

xowiki_portlet ad_proc add_self_to_page {
  {-portal_id:required}
  {-package_id:required}
} {
  Adds a PE to the given page
} {
  ns_log notice "xowiki_portlet::add_self_to_page - Don't call me. "
  error "don't call me"
}

xowiki_portlet ad_proc remove_self_from_page {
  portal_id
  element_id
} {
  Removes PE from the given page
} {
  # This is easy since there's one and only one instace_id
  portal::remove_element $element_id
}

xowiki_portlet ad_proc show {cf} {
  Show the portlet
} {
  portal::show_proc_helper \
      -package_key [:package_key] \
      -config_list $cf \
      -template_src "xowiki-portlet"
}

#
# install
#
xowiki_portlet proc install {} {
  :log "--portlet calling [self proc]"
  set name [:name]
  #
  # create the datasource
  #
  ::xo::dc transaction {
    set ds_id [portal::datasource::new \
                   -name $name \
                   -description "Displays an xowiki page as a portlet"]

    # default configuration
    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p t \
        -key "shadeable_p" -value t

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p t \
        -key "shaded_p" -value f

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p t \
        -key "hideable_p" -value t

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p t \
        -key "user_editable_p" -value f

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p t \
        -key "link_hideable_p" -value t

    # xowiki-specific configuration

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p f \
        -key "package_id" -value ""

    portal::datasource::set_def_param -datasource_id $ds_id \
        -config_required_p t -configured_p f \
        -key "page_name" -value ""

    #
    # service contract managemet
    #
    # create the implementation
    acs_sc::impl::new \
        -contract_name "portal_datasource" -name $name \
        -pretty_name "" -owner $name

    # add the operations
    foreach {operation call} {
      GetMyName          "xowiki_portlet name"
      GetPrettyName      "xowiki_portlet pretty_name"
      Link               "xowiki_portlet link"
      AddSelfToPage      "xowiki_portlet add_self_to_page"
      Show               "xowiki_portlet show"
      Edit               "xowiki_portlet edit"
      RemoveSelfFromPage "xowiki_portlet remove_self_from_page"
    } {
      acs_sc::impl::alias::new \
          -contract_name "portal_datasource" -impl_name $name \
          -operation $operation -alias $call \
          -language TCL
    }

    # Add the binding
    acs_sc::impl::binding::new \
        -contract_name "portal_datasource" -impl_name $name
  }
  :log "--portlet end of [self proc]"
}

#
# uninstall
#

xowiki_portlet proc uninstall {} {
  :log "--portlet calling [self proc]"
  #
  # completely identical to "xowiki_admin_portlet uninstall"
  #
  set name [:name]

  ::xo::dc transaction {
    #
    # get the datasource
    #
    set ds_id [::xo::dc get_value get_ds_id {
      select datasource_id from portal_datasources where name = :name
    } 0]

    if {$ds_id != 0} {
      #
      # drop the datasource
      #
      portal::datasource::delete -name $name
      #
    } else {
      ns_log notice "No datasource id found for $name"
    }

    #
    #  drop the implementation
    #
    acs_sc::impl::delete \
        -contract_name "portal_datasource" -impl_name $name
  }
  :log "--portlet end of [self proc]"
}

::xowiki_portlet proc after-install {} {
  ::xowiki_portlet install
  ::xowiki_admin_portlet install
}

::xowiki_portlet proc before-uninstall {} {
  ::xowiki_portlet uninstall
  ::xowiki_admin_portlet uninstall
}

# Local variables:
#    mode: tcl
#    tcl-indent-level: 2
#    indent-tabs-mode: nil
# End:
